@extends('layouts.panel')

@section('css')
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.5.2/css/bootstrap.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/2.0.5/css/dataTables.bootstrap4.css">

@endsection

@section('content')

    <div class="card shadow">
        <div class="card-header border-0">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="mb-0">Expedientes de Pacientes</h3>
                </div>
                
                <div class="col text-right">
                    <a href="{{ url('/especialidades/create') }}" class="btn btn-sm btn-primary">Nuevo Paciente</a>
                </div>

            </div>
        </div>
        <div class="card-body">
            @if (session('notification'))
                <div class="alert alert-success" role="alert">
                    {{ session('notification') }}
                </div>
            @endif
        </div>
    </div>
    <div class="card shadow">
        <div class="card">
            <div class="card-body">
                <div class="table-responsive">
                    <table id="pacientes" class="table align-items-center table-flush" style="width:100%">
                        <thead class="thead-light">
                            <tr>
                                <th>Receta</th>
                                <th>Folio</th>
                                <th>Nombre</th>
                                <th>Edad</th>
                                <th>IMG Diagnosticas</th>
                                <th>Usuario de modificación</th>
                                <th>Acciones</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($specialties as $especialidad)
                                <tr>
                                    <td>
                                    <!--Botones de la tabla -->
                                    <a href="{{ url('/especialidades/' . $especialidad->id . '/pdf') }}"
                                            class="btn-sm btn-primary" target="_blank">Receta</a>
                                    </td>
                                    <td>{{ $especialidad->id }}</td>
                                    <td>{{ $especialidad->name }}</td>
                                    <td>{{ $especialidad->edad }}</td>
                                    <td><img src="/public/images/{{ $especialidad->imgDiagnosticas }}" width="60%"></td>
                                    <td>{{ $especialidad->usuarioModifico }}</td>
                                    <td>
                                        <!--Botones de la tabla -->
                                        <form action="{{ url('/especialidades/' . $especialidad->id) }}" method="POST">
                                            @csrf
                                            @method('DELETE')
                                            <button type="submit"
                                                class="far fa-trash-alt btn btn-sm  btn-warning"></button>
                                            <a href="{{ url('/especialidades/' . $especialidad->id . '/edit') }}"
                                                class="fa fa-edit btn-sm btn-primary"></a>
                                            <a href="{{ url('/especialidades/' . $especialidad->id . '/expediente') }}"
                                                class="btn-sm btn-success" target="_blank">Expediente</a>
                                        </form>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js')
<script src="https://code.jquery.com/jquery-3.7.1.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.5.2/js/bootstrap.min.js"></script>
<script src="https://cdn.datatables.net/2.0.5/js/dataTables.js"></script>
<script src="https://cdn.datatables.net/2.0.5/js/dataTables.bootstrap4.js"></script>

<script>
  $(document).ready(function() {
    $('#pacientes').DataTable( {
        "language": {
            "lengthMenu": "Mostrar _MENU_ registros",
            "zeroRecords": "Nothing found - sorry",
            "info": "Mostrando la página _PAGE_ de _PAGES_",
            "infoEmpty": "No records available",
            "infoFiltered": "(Filtrado de _MAX_ registros totales)",
            'search': 'Buscar:'
        }
    } );
} );
</script>
    
@endsection